==> elemental2-dom-1.2.3.jar: elemental2/dom/GeolocationCoordinates.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsProperty;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;
import jsinterop.base.JsPropertyMap;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public interface GeolocationCoordinates {
  @JsOverlay
  static GeolocationCoordinates create() {
    return Js.uncheckedCast(JsPropertyMap.of());
  }

  @JsProperty
  double getAccuracy();

  @JsProperty
  double getAltitude();

  @JsProperty
  double getAltitudeAccuracy();

  @JsProperty
  double getHeading();

  @JsProperty
  double getLatitude();

  @JsProperty
  double getLongitude();

  @JsProperty
  double getSpeed();

  @JsProperty
  void setAccuracy(double accuracy);

  @JsProperty
  void setAltitude(double altitude);

  @JsProperty
  void setAltitudeAccuracy(double altitudeAccuracy);

  @JsProperty
  void setHeading(double heading);

  @JsProperty
  void setLatitude(double latitude);

  @JsProperty
  void setLongitude(double longitude);

  @JsProperty
  void setSpeed(double speed);
}

==> elemental2-dom-1.3.2.jar: elemental2/dom/GeolocationCoordinates.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import jsinterop.annotations.JsOverlay;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsProperty;
import jsinterop.annotations.JsType;
import jsinterop.base.Js;
import jsinterop.base.JsPropertyMap;
import org.jspecify.annotations.Nullable;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public interface GeolocationCoordinates {
  @JsOverlay
  static GeolocationCoordinates create() {
    return Js.uncheckedCast(JsPropertyMap.of());
  }

  @JsProperty
  double getAccuracy();

  @JsProperty
  @Nullable Double getAltitude();

  @JsProperty
  @Nullable Double getAltitudeAccuracy();

  @JsProperty
  @Nullable Double getHeading();

  @JsProperty
  double getLatitude();

  @JsProperty
  double getLongitude();

  @JsProperty
  @Nullable Double getSpeed();

  @JsProperty
  void setAccuracy(double accuracy);

  @JsProperty
  void setAltitude(@Nullable Double altitude);

  @JsProperty
  void setAltitudeAccuracy(@Nullable Double altitudeAccuracy);

  @JsProperty
  void setHeading(@Nullable Double heading);

  @JsProperty
  void setLatitude(double latitude);

  @JsProperty
  void setLongitude(double longitude);

  @JsProperty
  void setSpeed(@Nullable Double speed);
}
